@@ -60,7 +60,7 @@ void ChecksumSearchController::registerSearch(ChecksumSearchTransferDataSource *
             qCDebug(KGET_DEBUG) << "Creating download for" << baseUrl;
             static int files = 0;
 
-            const QUrl dest = QUrl(KStandardDirs::locateLocal("appdata", "checksumsearch/") + QString::number(files++));
+            const QUrl dest = QUrl::fromLocalFile(KStandardDirs::locateLocal("appdata", "checksumsearch/") + QString::number(files++));
             if (QFile::exists(dest.toLocalFile())) {
                 KIO::Job *del = KIO::del(dest, KIO::HideProgressInfo);
                 KIO::NetAccess::synchronousRun(del, nullptr);
